.. prem-python-sdk documentation master file, created by
   sphinx-quickstart on Sat Dec 16 16:43:20 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to prem-python-sdk's documentation!
===========================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   prem.client
   prem.resources

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
